@@ -5,6 +5,7 @@ use warnings;
 use strict;
 use Carp;
 
+=encoding utf8
 
 =head1 NAME
 
@@ -12,11 +13,11 @@ Device::USB::Bus - Use libusb to access USB devices.
 
 =head1 VERSION
 
-Version 0.12
+Version 0.38
 
 =cut
 
-our $VERSION=0.12;
+our $VERSION=0.38;
 
 =head1 SYNOPSIS
 
@@ -35,9 +36,9 @@ supports Perl code controlling and accessing USB devices.
     {
         print $bus->dirname(), ":\n";
         foreach my $dev ($bus->devices())
-	{
-	    print "\t", $dev->filename(), "\n";
-	}
+        {
+            print "\t", $dev->filename(), "\n";
+        }
     }
 
 
@@ -121,7 +122,7 @@ sub find_device_if
     croak( "Predicate must be a code reference.\n" )
         unless 'CODE' eq ref $pred;
 
-    local $_;
+    local $_ = undef;
 
     foreach($self->devices())
     {
@@ -167,7 +168,7 @@ sub list_devices_if
     croak( "Predicate must be a code reference.\n" )
         unless 'CODE' eq ref $pred;
 
-    local $_;
+    local $_ = undef;
 
     my @devices = grep { $pred->() } $self->devices();
 
@@ -189,7 +190,7 @@ that is the entire reason for the module's existence.
 
 =head1 AUTHOR
 
-G. Wade Johnson (wade at anomaly dot org)
+G. Wade Johnson (gwadej at cpan dot org)
 Paul Archer (paul at paularcher dot org)
 
 Houston Perl Mongers Group
@@ -213,7 +214,7 @@ spotting, reporting, and (sometimes) fixing bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Houston Perl Mongers
+Copyright 2006-2013 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
